==> haskell-data-serializer-0.3.2-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-data-serializer.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-serializer
version: 0.3.2
id: data-serializer-0.3.2-FEVbDn4WCZMByBRzUf6F7G
key: data-serializer-0.3.2-FEVbDn4WCZMByBRzUf6F7G
license: BSD3
copyright: 2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-serializer
synopsis: Common API for serialization libraries
description:
    This package provides a common API for serialization libraries like
    <http://hackage.haskell.org/package/binary binary> and
    <http://hackage.haskell.org/package/cereal cereal>.
category: Data
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Deserializer Data.Serializer
abi: 6d06fdfecbd0ae2a1266afe627d5236b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/data-serializer-0.3.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/data-serializer-0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/data-serializer-0.3.2
hs-libraries: HSdata-serializer-0.3.2-FEVbDn4WCZMByBRzUf6F7G
depends:
    base-4.10.1.0 semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7
    bytestring-0.10.8.2 binary-0.8.5.1
    cereal-0.5.4.0-HHG4trmDAey7tG5Rc3nyML
    data-endian-0.1.1-LZbtoj85OezF7hILfqR1PR
    parsers-0.12.8-Abz77y9BLpNDRy3rTFzWBH
    split-0.2.3.2-7cayvoeRj5XIrIBUB58mMy
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7=d64b81e3ed8022aca04423ee7b330679
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             binary-0.8.5.1=33c677d3ced9a5afbc7b354509494653
             cereal-0.5.4.0-HHG4trmDAey7tG5Rc3nyML=ed459ea038cbdb253abe2c011f65c556
             data-endian-0.1.1-LZbtoj85OezF7hILfqR1PR=5308194b84273b427972c64485f8ac88
             parsers-0.12.8-Abz77y9BLpNDRy3rTFzWBH=ac9ae2986b3ba3a0c3f2c770b504e5ff
             split-0.2.3.2-7cayvoeRj5XIrIBUB58mMy=797cd4cd973bcc2d6f301fd097dd3406
haddock-interfaces: /usr/share/doc/haskell-data-serializer/html/data-serializer.haddock
haddock-html: /usr/share/doc/haskell-data-serializer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-serializer-0.3.2-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-data-serializer.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-serializer
version: 0.3.2
id: data-serializer-0.3.2-IqYM5rioomq6zdQizlIG1k
key: data-serializer-0.3.2-IqYM5rioomq6zdQizlIG1k
license: BSD3
copyright: 2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-serializer
synopsis: Common API for serialization libraries
description:
    This package provides a common API for serialization libraries like
    <http://hackage.haskell.org/package/binary binary> and
    <http://hackage.haskell.org/package/cereal cereal>.
category: Data
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Deserializer Data.Serializer
abi: 9a46052efde8ed0a27cf742d99142cfd
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/data-serializer-0.3.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/data-serializer-0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/data-serializer-0.3.2
hs-libraries: HSdata-serializer-0.3.2-IqYM5rioomq6zdQizlIG1k
depends:
    base-4.10.1.0 semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7
    bytestring-0.10.8.2 binary-0.8.5.1
    cereal-0.5.4.0-HHG4trmDAey7tG5Rc3nyML
    data-endian-0.1.1-LZbtoj85OezF7hILfqR1PR
    parsers-0.12.8-FP2u5JK1pN298aUVOsbisC
    split-0.2.3.3-BN2ylJ9hXZBIaY8HiUVge7
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7=d64b81e3ed8022aca04423ee7b330679
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             binary-0.8.5.1=33c677d3ced9a5afbc7b354509494653
             cereal-0.5.4.0-HHG4trmDAey7tG5Rc3nyML=ed459ea038cbdb253abe2c011f65c556
             data-endian-0.1.1-LZbtoj85OezF7hILfqR1PR=5308194b84273b427972c64485f8ac88
             parsers-0.12.8-FP2u5JK1pN298aUVOsbisC=7c855c4d3999028d952d112825a5a901
             split-0.2.3.3-BN2ylJ9hXZBIaY8HiUVge7=b6b8499789ca23888d2f286cbdde6707
haddock-interfaces: /usr/share/doc/haskell-data-serializer/html/data-serializer.haddock
haddock-html: /usr/share/doc/haskell-data-serializer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
